# PipelineTS

一站式时间序列分析工具，支持时序数据预处理、特征工程、模型训练、模型评估、模型预测等。

## 安装

```bash
pip install PipelineTS
```

## 快速开始

### 数据准备

```python
# TODO
```

### 预处理

```python
# TODO
```

### 特征工程

```python
# TODO
```

### 模型训练

```python
# TODO
```

### 模型评估    

```python
# TODO
```

### 模型预测

```python
# TODO
```

### 模型部署

```python
# TODO
```